@@ -2,6 +2,7 @@ import os
 import ssl
 import shutil
 import socket
+import collections
 
 from OpenSSL import crypto  # type: ignore
 
@@ -45,24 +46,37 @@ class CertDir:
         self.crypto_numbits = 4096
         self.signing_digest = 'sha256'
 
-        if path is None:
-            path = defdir
-
         self.certdirs = []
+        self.pathrefs = collections.defaultdict(int)
 
-        # for backward compatibility, do some type inspection
-        if isinstance(path, str):
-            self.certdirs.append(s_common.gendir(path))
-        elif isinstance(path, (tuple, list)):
-            [self.certdirs.append(s_common.gendir(p)) for p in path]
-        else:
-            mesg = 'Certdir path must be a path string or a list/tuple of path strings.'
-            raise s_exc.SynErr(mesg=mesg)
+        if path is None:
+            path = (defdir,)
 
-        for cdir in self.certdirs:
-            s_common.gendir(cdir, 'cas')
-            s_common.gendir(cdir, 'hosts')
-            s_common.gendir(cdir, 'users')
+        if not isinstance(path, (list, tuple)):
+            path = (path,)
+
+        for p in path:
+            self.addCertPath(p)
+
+    def addCertPath(self, *path):
+
+        fullpath = s_common.gendir(*path)
+        self.pathrefs[fullpath] += 1
+
+        if self.pathrefs[fullpath] == 1:
+
+            self.certdirs.append(fullpath)
+
+            s_common.gendir(fullpath, 'cas')
+            s_common.gendir(fullpath, 'hosts')
+            s_common.gendir(fullpath, 'users')
+
+    def delCertPath(self, *path):
+        fullpath = s_common.gendir(*path)
+        self.pathrefs[fullpath] -= 1
+        if self.pathrefs[fullpath] <= 0:
+            self.certdirs.remove(fullpath)
+            self.pathrefs.pop(fullpath, None)
 
     def genCaCert(self, name, signas=None, outp=None, save=True):
         '''
@@ -839,8 +853,13 @@ class CertDir:
         return self.genUserCert(name, csr=pkey, signas=signas, outp=outp)
 
     def _loadCasIntoSSLContext(self, ctx):
+
         for cdir in self.certdirs:
+
             path = s_common.genpath(cdir, 'cas')
+            if not os.path.isdir(path):
+                continue
+
             for name in os.listdir(path):
                 if name.endswith('.crt'):
                     ctx.load_verify_locations(os.path.join(path, name))
@@ -857,17 +876,27 @@ class CertDir:
         self._loadCasIntoSSLContext(sslctx)
 
         if certname is not None:
-            certfile = self.getUserCertPath(certname)
-            if certfile is None:
-                mesg = f'Missing TLS certificate file for user: {certname}'
+
+            username = certname
+            if username.find('@') != -1:
+                user, host = username.split('@', 1)
+                username = self.getUserForHost(user, host)
+
+            if username is None:
+                mesg = f'User certificate not found: {certname}'
                 raise s_exc.NoSuchCert(mesg=mesg)
 
-            keyfile = self.getUserKeyPath(certname)
-            if keyfile is None:
-                mesg = f'Missing TLS key file for user: {certname}'
+            certpath = self.getUserCertPath(username)
+            if certpath is None:
+                mesg = f'User certificate not found: {certname}'
+                raise s_exc.NoSuchCert(mesg=mesg)
+
+            keypath = self.getUserKeyPath(username)
+            if keypath is None:
+                mesg = f'User private key not found: {certname}'
                 raise s_exc.NoCertKey(mesg=mesg)
 
-            sslctx.load_cert_chain(certfile, keyfile)
+            sslctx.load_cert_chain(certpath, keypath)
 
         return sslctx
 
@@ -962,13 +991,17 @@ class CertDir:
         csrpath = self._getPathJoin(mode, '%s.csr' % name)
         self._checkDupFile(csrpath)
 
+        byts = crypto.dump_certificate_request(crypto.FILETYPE_PEM, xcsr)
+
         with s_common.genfile(csrpath) as fd:
             fd.truncate(0)
-            fd.write(crypto.dump_certificate_request(crypto.FILETYPE_PEM, xcsr))
+            fd.write(byts)
 
         if outp is not None:
             outp.printf('csr saved: %s' % (csrpath,))
 
+        return byts
+
     def _getCaPath(self, cert):
         subj = cert.get_issuer()
         return self.getCaCertPath(subj.CN)
@@ -989,7 +1022,10 @@ class CertDir:
     def _loadCsrPath(self, path):
         byts = self._getPathBytes(path)
         if byts:
-            return crypto.load_certificate_request(crypto.FILETYPE_PEM, byts)
+            return self._loadCsrByts(byts)
+
+    def _loadCsrByts(self, byts):
+        return crypto.load_certificate_request(crypto.FILETYPE_PEM, byts)
 
     def _loadKeyPath(self, path):
         byts = self._getPathBytes(path)
@@ -1007,17 +1043,23 @@ class CertDir:
 
         with s_common.genfile(path) as fd:
             fd.truncate(0)
-            fd.write(crypto.dump_certificate(crypto.FILETYPE_PEM, cert))
+            fd.write(self._certToByts(cert))
 
         return path
 
+    def _certToByts(self, cert):
+        return crypto.dump_certificate(crypto.FILETYPE_PEM, cert)
+
+    def _pkeyToByts(self, pkey):
+        return crypto.dump_privatekey(crypto.FILETYPE_PEM, pkey)
+
     def _savePkeyTo(self, pkey, *paths):
         path = self._getPathJoin(*paths)
         self._checkDupFile(path)
 
         with s_common.genfile(path) as fd:
             fd.truncate(0)
-            fd.write(crypto.dump_privatekey(crypto.FILETYPE_PEM, pkey))
+            fd.write(self._pkeyToByts(pkey))
 
         return path
 
@@ -1030,3 +1072,13 @@ class CertDir:
             fd.write(cert.export())
 
         return path
+
+certdir = CertDir()
+def getCertDir():
+    return certdir
+
+def addCertPath(path):
+    return certdir.addCertPath(path)
+
+def delCertPath(path):
+    return certdir.delCertPath(path)
