@@ -6,6 +6,7 @@ import synapse.common as s_common
 import synapse.telepath as s_telepath
 import synapse.datamodel as s_datamodel
 
+import synapse.lib.coro as s_coro
 import synapse.lib.storm as s_storm
 import synapse.lib.version as s_version
 import synapse.lib.httpapi as s_httpapi
@@ -215,9 +216,9 @@ class StormTest(s_t_utils.SynTest):
             ''')
             self.eq(email, 'visi@vertex.link')
 
-            pkg0 = {'name': 'hehe', 'version': (1, 2, 3)}
+            pkg0 = {'name': 'hehe', 'version': '1.2.3'}
             await core.addStormPkg(pkg0)
-            self.eq((1, 2, 3), await core.callStorm('return($lib.pkg.get(hehe).version)'))
+            self.eq('1.2.3', await core.callStorm('return($lib.pkg.get(hehe).version)'))
 
             # test for $lib.queue.gen()
             self.eq(0, await core.callStorm('return($lib.queue.gen(woot).size())'))
@@ -259,6 +260,134 @@ class StormTest(s_t_utils.SynTest):
                 self.false(await proxy.disableStormDmon('newp'))
                 self.false(await proxy.enableStormDmon('newp'))
 
+            await core.callStorm('[ inet:ipv4=11.22.33.44 :asn=56 inet:asn=99]')
+            await core.callStorm('[ ps:person=* +#foo ]')
+
+            view, layr = await core.callStorm('$view = $lib.view.get().fork() return(($view.iden, $view.layers.0.iden))')
+
+            opts = {'view': view}
+            self.len(0, await core.callStorm('''
+                $list = $lib.list()
+                $layr = $lib.view.get().layers.0
+                for $item in $layr.getStorNodes() {
+                    $list.append($item)
+                }
+                return($list)''', opts=opts))
+
+            await core.addTagProp('score', ('int', {}), {})
+            await core.callStorm('[ inet:ipv4=11.22.33.44 :asn=99 inet:fqdn=55667788.link +#foo=2020 +#foo:score=100]', opts=opts)
+            await core.callStorm('inet:ipv4=11.22.33.44 $node.data.set(foo, bar)', opts=opts)
+            await core.callStorm('inet:ipv4=11.22.33.44 [ +(blahverb)> { inet:asn=99 } ]', opts=opts)
+
+            sodes = await core.callStorm('''
+                $list = $lib.list()
+                $layr = $lib.view.get().layers.0
+                for $item in $layr.getStorNodes() {
+                    $list.append($item)
+                }
+                return($list)''', opts=opts)
+            self.len(2, sodes)
+
+            ipv4 = await core.callStorm('''
+                $list = $lib.list()
+                $layr = $lib.view.get().layers.0
+                for ($buid, $sode) in $layr.getStorNodes() {
+                    yield $buid
+                }
+                +inet:ipv4
+                return($node.repr())''', opts=opts)
+            self.eq('11.22.33.44', ipv4)
+
+            sodes = await core.callStorm('inet:ipv4=11.22.33.44 return($node.getStorNodes())', opts=opts)
+            self.eq((1577836800000, 1577836800001), sodes[0]['tags']['foo'])
+            self.eq((99, 9), sodes[0]['props']['asn'])
+            self.eq((185999660, 4), sodes[1]['valu'])
+            self.eq(('unicast', 1), sodes[1]['props']['type'])
+            self.eq((56, 9), sodes[1]['props']['asn'])
+
+            bylayer = await core.callStorm('inet:ipv4=11.22.33.44 return($node.getByLayer())', opts=opts)
+            self.ne(bylayer['ndef'], layr)
+            self.eq(bylayer['props']['asn'], layr)
+            self.eq(bylayer['tags']['foo'], layr)
+            self.ne(bylayer['props']['type'], layr)
+
+            msgs = await core.stormlist('inet:ipv4=11.22.33.44 | merge', opts=opts)
+            self.stormIsInPrint('aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4:asn = 99', msgs)
+            self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4#foo = ('2020/01/01 00:00:00.000', '2020/01/01 00:00:00.001')", msgs)
+            self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4#foo:score = 100", msgs)
+            self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4 DATA foo = 'bar'", msgs)
+            self.stormIsInPrint('aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4 +(blahverb)> a0df14eab785847912993519f5606bbe741ad81afb51b81455ac6982a5686436', msgs)
+
+            await core.callStorm('inet:ipv4=11.22.33.44 | merge --apply', opts=opts)
+            nodes = await core.nodes('inet:ipv4=11.22.33.44')
+            self.len(1, nodes)
+            self.nn(nodes[0].getTag('foo'))
+            self.eq(99, nodes[0].get('asn'))
+
+            bylayer = await core.callStorm('inet:ipv4=11.22.33.44 return($node.getByLayer())', opts=opts)
+            self.ne(bylayer['ndef'], layr)
+            self.ne(bylayer['props']['asn'], layr)
+            self.ne(bylayer['tags']['foo'], layr)
+
+            # confirm that we moved node data and light edges
+            self.eq('bar', await core.callStorm('inet:ipv4=11.22.33.44 return($node.data.get(foo))'))
+            self.eq(99, await core.callStorm('inet:ipv4=11.22.33.44 -(blahverb)> inet:asn return($node.value())'))
+            self.eq(100, await core.callStorm('inet:ipv4=11.22.33.44 return(#foo:score)'))
+
+            sodes = await core.callStorm('inet:ipv4=11.22.33.44 return($node.getStorNodes())', opts=opts)
+            self.eq(sodes[0], {})
+
+            with self.raises(s_exc.CantMergeView):
+                await core.callStorm('inet:ipv4=11.22.33.44 | merge')
+
+            # test printing a merge that the node was created in the top layer
+            msgs = await core.stormlist('[ inet:fqdn=mvmnasde.com ] | merge', opts=opts)
+            self.stormIsInPrint('3496c02183961db4fbc179f0ceb5526347b37d8ff278279917b6eb6d39e1e272 inet:fqdn = mvmnasde.com', msgs)
+            self.stormIsInPrint('3496c02183961db4fbc179f0ceb5526347b37d8ff278279917b6eb6d39e1e272 inet:fqdn:host = mvmnasde', msgs)
+            self.stormIsInPrint('3496c02183961db4fbc179f0ceb5526347b37d8ff278279917b6eb6d39e1e272 inet:fqdn:domain = com', msgs)
+            self.stormIsInPrint('3496c02183961db4fbc179f0ceb5526347b37d8ff278279917b6eb6d39e1e272 inet:fqdn:issuffix = False', msgs)
+            self.stormIsInPrint('3496c02183961db4fbc179f0ceb5526347b37d8ff278279917b6eb6d39e1e272 inet:fqdn:iszone = True', msgs)
+            self.stormIsInPrint('3496c02183961db4fbc179f0ceb5526347b37d8ff278279917b6eb6d39e1e272 inet:fqdn:zone = mvmnasde.com', msgs)
+
+            # merge all the nodes with anything stored in the top layer...
+            await core.callStorm('''
+                for ($buid, $sode) in $lib.view.get().layers.0.getStorNodes() {
+                    yield $buid
+                }
+                | merge --apply
+            ''', opts=opts)
+
+            self.len(0, await core.callStorm('''
+                $list = $lib.list()
+                for ($buid, $sode) in $lib.view.get().layers.0.getStorNodes() {
+                    $list.append($buid)
+                }
+                return($list)
+            ''', opts=opts))
+
+            self.eq('c8af8cfbcc36ba5dec9858124f8f014d', await core.callStorm('''
+                $iden = c8af8cfbcc36ba5dec9858124f8f014d
+                [ inet:fqdn=vertex.link <(woots)+ {[ meta:source=$iden ]} ]
+                <(woots)- meta:source
+                return($node.value())
+            '''))
+
+            with self.raises(s_exc.BadArg):
+                await core.callStorm('inet:fqdn=vertex.link $tags = $node.globtags(foo.***)')
+
+            nodes = await core.nodes('$form=inet:fqdn [ *$form=visi.com ]')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef, ('inet:fqdn', 'visi.com'))
+
+            # test non-runtsafe invalid form deref node add
+            with self.raises(s_exc.NoSuchForm):
+                await core.callStorm('[ it:dev:str=hehe:haha ] $form=$node.value() [*$form=lol]')
+
+            async def sleeper():
+                await asyncio.sleep(2)
+            task = core.schedCoro(sleeper())
+            self.false(await s_coro.waittask(task, timeout=0.1))
+
     async def test_storm_pipe(self):
 
         async with self.getTestCore() as core:
@@ -380,7 +509,7 @@ class StormTest(s_t_utils.SynTest):
         cont = s_common.guid()
         pkg = {
             'name': 'testload',
-            'version': (0, 3, 0),
+            'version': '0.3.0',
             'modules': (
                 {
                     'name': 'testload',
@@ -1536,7 +1665,7 @@ class StormTest(s_t_utils.SynTest):
                         await asvisi.callStorm(f'$lib.layer.get($layr2).delPull(hehe)', opts=opts)
 
                 actv = len(core.activecoros)
-                #view0 -push-> view1 <-pull- view2
+                # view0 -push-> view1 <-pull- view2
                 await core.callStorm(f'$lib.layer.get($layr0).addPush("tcp://root:secret@127.0.0.1:{port}/*/layer/{layr1}")', opts=opts)
                 await core.callStorm(f'$lib.layer.get($layr2).addPull("tcp://root:secret@127.0.0.1:{port}/*/layer/{layr1}")', opts=opts)
 
@@ -1550,7 +1679,7 @@ class StormTest(s_t_utils.SynTest):
                 self.len(1, [t for t in tasks if t.get('name').startswith('layer pull:')])
                 self.len(1, [t for t in tasks if t.get('name').startswith('layer push:')])
 
-                offs = await core.layers.get(layr2).getEditOffs(defv=-1)
+                offs = await core.layers.get(layr2).getEditOffs()
                 await core.nodes('[ ps:contact=* ]', opts={'view': view0})
                 await core.layers.get(layr2).waitEditOffs(offs + 1, timeout=3)
                 self.len(1, await core.nodes('ps:contact', opts={'view': view2}))
@@ -1564,7 +1693,7 @@ class StormTest(s_t_utils.SynTest):
 
                 await asyncio.sleep(0)
 
-                offs = await core.layers.get(layr2).getEditOffs(defv=-1)
+                offs = await core.layers.get(layr2).getEditOffs()
                 await core.nodes('[ ps:contact=* ]', opts={'view': view0})
                 await core.layers.get(layr2).waitEditOffs(offs + 1, timeout=3)
 
@@ -1605,6 +1734,8 @@ class StormTest(s_t_utils.SynTest):
                 self.len(1, [t for t in tasks if t.get('name').startswith('layer push:')])
                 self.eq(actv, len(core.activecoros))
 
+                tasks = [cdef.get('task') for cdef in core.activecoros.values()]
+
                 await core.callStorm('$lib.view.del($view0)', opts=opts)
                 await core.callStorm('$lib.view.del($view1)', opts=opts)
                 await core.callStorm('$lib.view.del($view2)', opts=opts)
@@ -1612,7 +1743,9 @@ class StormTest(s_t_utils.SynTest):
                 await core.callStorm('$lib.layer.del($layr1)', opts=opts)
                 await core.callStorm('$lib.layer.del($layr2)', opts=opts)
 
-                await asyncio.sleep(0)
+                # Wait for the active coros to die
+                for task in [t for t in tasks if t is not None]:
+                    await s_coro.waittask(task, timeout=5)
 
                 tasks = await core.callStorm('return($lib.ps.list())')
                 self.len(0, [t for t in tasks if t.get('name').startswith('layer pull:')])
